@@ -2,10 +2,22 @@ class AIQPYException(Exception):
     pass
 
 
+class ConnectionError(AIQPYException):
+    pass
+
+
 class LoginError(AIQPYException):
     pass
 
 
+class MalformedURLException(AIQPYException):
+    pass
+
+
+class MissingEndpointException(AIQPYException):
+    pass
+
+
 class OrganizationNotFoundException(AIQPYException):
     pass
 
